Index: web/src/main/webapp/AddImages.html
===================================================================
--- web/src/main/webapp/AddImages.html	(revision 7026)
+++ web/src/main/webapp/AddImages.html	(working copy)
@@ -17,7 +17,6 @@
     <script src="lib/swfobject/js/swfobject.js" type="text/javascript"></script>
     <script src="lib/swfupload/js/swfupload.js" type="text/javascript"></script>
     <script src="framework/core/js/Fluid.js" type="text/javascript"></script>
-    <script src="framework/core/js/ProgressiveEnhancement.js" type="text/javascript"></script>
     
     <!-- Uploader dependencies -->
     <script src="components/uploader/js/FileQueue.js" type="text/javascript"></script>
@@ -46,12 +45,6 @@
     <div>Upload images from your Computer to <em>All Images</em></div>
     <!-- Uploader will be injected in here. -->
     <div id="uploader"></div>
-    
-    <script type="text/javascript">
-        /* <![CDATA[ */
-            initUploader();
-        /* ]]> */
-    </script>
 </div>
 
 </body>
Index: web/src/main/webapp/js/image-gallery.js
===================================================================
--- web/src/main/webapp/js/image-gallery.js	(revision 7026)
+++ web/src/main/webapp/js/image-gallery.js	(working copy)
@@ -1,43 +1,57 @@
-/* Javascript for the Image-Gallery 2 project */
+/*
+Copyright 2007-2009 University of California, Berkeley
+Copyright 2008-2009 University of Toronto
 
+Licensed under the Educational Community License (ECL), Version 2.0 or the New
+BSD license. You may not use this file except in compliance with one these
+Licenses.
+
+You may obtain a copy of the ECL 2.0 License and BSD License at
+https://source.fluidproject.org/svn/LICENSE.txt
+*/
+
+/*global jQuery,fluid,gallery,myUpload*/
+
+var gallery = gallery || {};
 var myUpload;
 
-var initUploader = function () {  
-    jQuery(function () {
-        jQuery("#uploader").load("../../components/uploader/html/Uploader.html #uploader-contents", null, function () {
+(function ($) {
+    
+    /**
+     * Initializes the Infusion Uploader for the AddImages page.
+     */
+    gallery.initUploader = function () {
+        $("#uploader").load("../../components/uploader/html/Uploader.html #uploader-contents", null, function () {
+        
+            // Show the Uploader's markup immediately, since we're not using progressive enhancement.
+            $(".fl-ProgEnhance-basic").hide();
+            $(".fl-ProgEnhance-enhanced").show();
+                    
+            // Add the form action.
+            $(".flc-uploader").attr("action", "site/AddInformationToImages");
             
-            // Add the form actions.
-            jQuery(".fl-uploader").attr("action", "site/AddInformationToImages");
-            jQuery(".fl-progressive-enhanceable").attr("action", "site/singleFileUpload");
-            
             // Initialize the Uploader.
-            myUpload = fluid.progressiveEnhanceableUploader(".flc-uploader", ".fl-ProgEnhance-basic", {
+            myUpload = fluid.uploader(".flc-uploader", {
                 uploadManager: {
                     type: "fluid.swfUploadManager",
                         
                     options: {
                         flashURL: "../../lib/swfupload/flash/swfupload.swf",
-                        uploadURL: "../../../site/multiFileUpload",
+                        
+                        // FLUID-2464: For some reason, we seem to have to use an absolute-ish path
+                        // in order for uploads to work in both browsers. Seems to have something to do with
+                        // the way Flash handles relative paths.
+                        uploadURL: "/sakai-imagegallery2-web/site/multiFileUpload",
                         fileTypes: "*.gif;*.jpeg;*.jpg;*.png;*.tiff",
                         debug: true
                     }
                 },
                 
                 listeners: {
-                    afterFileUploaded: function (file, serverData){
-         				// Keep track of what's been added in this go-round so that those
-        				// images can be shown on the next page. (Alternatively, you
-        				// might set up another panel on this page to accumulate thumbnails
-        				// as each file is successfully consumed.)
-        				jQuery('#new-image-form').append('<input type="hidden" name="imageIds" value="' + 
-                                                         serverResponse + '"/>');
-                    },
-                    
-          
                     afterUploadComplete: function () {
                         if (myUpload.uploadManager.queue.getReadyFiles().length === 0 && myUpload.uploadManager.queue.getErroredFiles().length === 0) { // we're really really done
-                             window.location.href = "/sakai-imagegallery2-web/site/BrowseImages/";
-                         }
+                            window.location.href = "../BrowseImages/";
+                        }
                     }
                 },
                 
@@ -49,5 +63,8 @@
                 }
             });
         });
-    });
-};      
\ No newline at end of file
+    };
+    
+    // Initialize the Uploader as soon as the DOM is ready.
+    $(gallery.initUploader);
+})(jQuery);

Index: development-support/clean-build-run.sh
===================================================================
--- development-support/clean-build-run.sh	(revision 7026)
+++ development-support/clean-build-run.sh	(working copy)
@@ -1,12 +1,18 @@
 REPO=`pwd`/..
-COMPONENTS=$REPO/components
+COMPONENTS=$REPO/infusion
 GALLERY=$REPO/image-gallery
 
 # Delete the sticky fluid-components directory from image-gallery first.
 cd $GALLERY/web/src/main/webapp/
-rm -rf fluid-components
+rm -rf components
+rm -rf framework
+rm -rf integration-demos
+rm -rf lib
+rm -rf sample-code
+rm -rf standalone-demos
+rm -rf tests 
 
-# Build fluid-components
+# Build Infusion 
 cd $COMPONENTS
 mvn clean install
 
@@ -1,12 +1,18 @@
 GALLERY=$REPO/image-gallery
 
-# Delete the sticky fluid-components directory from image-gallery first.
+# Delete the sticky Infusion directories from image-gallery first.
 cd $GALLERY/web/src/main/webapp/